@@ -19,6 +19,12 @@ OC.L10N.register(
     "You created the conversation" : "Sinä loit keskustelun",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} muutti keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Sinä muutit keskustelun \"%1$s\" uudeksi nimeksi \"%2$s\"",
+    "{actor} set the description" : "{actor} asetti kuvauksen",
+    "You set the description" : "Sinä asetit kuvauksen",
+    "An administrator set the description" : "Ylläpitäjä asetti kuvauksen",
+    "{actor} removed the description" : "{actor} poisti kuvauksen",
+    "You removed the description" : "Sinä poistit kuvauksen",
+    "An administrator removed the description" : "Ylläpitäjä poisti kuvauksen",
     "{actor} started a call" : "{actor} aloitti puhelun",
     "You started a call" : "Sinä aloitit puhelun",
     "{actor} joined the call" : "{actor} liittyi puheluun",
@@ -27,8 +33,10 @@ OC.L10N.register(
     "You left the call" : "Sinä poistuit puhelusta",
     "{actor} unlocked the conversation" : "{actor} poisti keskustelun lukituksen",
     "You unlocked the conversation" : "Poistit keskustelun lukituksen",
+    "An administrator unlocked the conversation" : "Ylläpitäjä poisti keskustelun lukituksen",
     "{actor} locked the conversation" : "{actor} lukitsi keskustelun",
     "You locked the conversation" : "Sinä lukitsit keskustelun",
+    "An administrator locked the conversation" : "Ylläpitäjä lukitsi keskustelun",
     "The conversation is now open to everyone" : "Keskustelu on nyt avoin kaikille",
     "{actor} opened the conversation to everyone" : "{actor} avasi keskustelun kaikille",
     "You opened the conversation to everyone" : "Avasit uuden keskustelun kaikille",
@@ -38,18 +46,28 @@ OC.L10N.register(
     "You disallowed guests" : "Sinä estit vieraat",
     "{actor} set a password" : "{actor} asetti salasanan",
     "You set a password" : "Sinä asetit salasanan",
+    "An administrator set a password" : "Ylläpitäjä asetti salasanan",
     "{actor} removed the password" : "{actor} poisti salasanan",
     "You removed the password" : "Sinä poistit salasanan",
+    "An administrator removed the password" : "Ylläpitäjä poisti salasanan",
     "{actor} added {user}" : "{actor} lisäsi käyttäjän {user}",
     "You joined the conversation" : "Liityit keskusteluun",
     "{actor} joined the conversation" : "{actor} liittyi keskusteluun",
     "You added {user}" : "Sinä lisäsit käyttäjän {user}",
     "{actor} added you" : "{actor} lisäsi sinut",
+    "An administrator added you" : "Ylläpitäjä lisäsi sinut",
     "You left the conversation" : "Poistuit keskustelusta",
     "{actor} left the conversation" : "{actor} poistui keskustelusta",
     "{actor} removed {user}" : "{actor} poisti käyttäjän {user}",
     "You removed {user}" : "Sinä poistit käyttäjän {user}",
     "{actor} removed you" : "{actor} poisti sinut",
+    "An administrator removed you" : "Ylläpitäjä lisäsi sinut",
+    "{actor} added group {group}" : "{actor} lisäsi ryhmän {group}",
+    "You added group {group}" : "Lisäsit ryhmän {group}",
+    "An administrator added group {group}" : "Ylläpitäjä lisäsi ryhmän {group}",
+    "{actor} removed group {group}" : "{actor} poisti ryhmän {group}",
+    "You removed group {group}" : "Poistit ryhmän {group}",
+    "An administrator removed group {group}" : "Ylläpitäjä poisti ryhmän {group}",
     "{actor} promoted {user} to moderator" : "{actor} nosti käyttäjän {user} moderaattoriksi",
     "You promoted {user} to moderator" : "Sinä nostit käyttäjän {user} moderaattoriksi",
     "{actor} promoted you to moderator" : "{actor} nosti sinut moderaattoriksi",
@@ -58,12 +76,18 @@ OC.L10N.register(
     "{actor} demoted you from moderator" : "{actor} poisti sinulta moderaattorin oikeudet",
     "{actor} shared a file which is no longer available" : "{actor} jakoi kanssasi tiedoston, joka ei ole enää saatavilla",
     "You shared a file which is no longer available" : "Jaoit tiedoston, joka ei ole enää saatavilla",
+    "{actor} deleted a message" : "{actor} poisti viestin",
+    "You deleted a message" : "Sinä poistit viestin",
+    "{actor} cleared the history of the conversation" : "{actor} tyhjensi keskusteluhistorian",
+    "You cleared the history of the conversation" : "Sinä tyhjensit keskusteluhistorian",
     "%s (guest)" : "%s (vieras)",
     "You missed a call from {user}" : "Sinulta jäi vastaamatta puhelu käyttäjältä {user}",
     "Call with {user1} and {user2} (Duration {duration})" : "Puhelu käyttäjien {user1} ja {user2} kesken (Kesto {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2} ja {user3} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3} ja {user4} kesken (Kesto {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Puhelu käyttäjien {user1}, {user2}, {user3}, {user4} ja {user5} kesken (Kesto {duration})",
+    "File is too big" : "Tiedosto on liian suuri",
+    "Unknown filetype" : "Tuntematon tiedostotyyppi",
     "Write to conversation" : "Kirjoita keskusteluun",
     "%s invited you to a conversation." : "%s kutsui sinut keskusteluun.",
     "You were invited to a conversation." : "Sinut kutsuttiin keskusteluun.",
@@ -148,6 +172,7 @@ OC.L10N.register(
     "Tunisia" : "Tunisia",
     "Turkey" : "Turkki",
     "Ukraine" : "Ukraina",
+    "United States of America" : "Yhdysvallat",
     "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päiväyksen muoto tulee olla YYYY-MM-DD",
     "Conversation not found" : "Keskustelua ei löydy",
     "Path is already shared with this room" : "Polku on jo jaettu tämän huoneen kesken",
@@ -249,17 +274,27 @@ OC.L10N.register(
     "Call in progress" : "Puhelu meneillään",
     "Favorite" : "Suosikki",
     "Conversation settings" : "Keskustelun asetukset",
+    "Description" : "Kuvaus",
+    "Enter a description for this conversation" : "Anna kuvaus tälle keskustelulle",
     "Chat notifications" : "Keskusteluilmoitukset",
+    "Meeting settings" : "Kokouksen asetukset",
     "Leave conversation" : "Poistu keskustelusta",
     "Delete conversation" : "Poista keskustelu",
     "Do you really want to delete \"{displayName}\"?" : "Poistetaanko \"{displayName}\"?",
     "Password protection" : "Salasanasuojaus",
     "Enter a password" : "Syötä salasana",
+    "Save password" : "Tallenna salasana",
     "Copy conversation link" : "Kopioi keskustelulinkki",
+    "Resend invitations" : "Lähetä kutsut uudelleen",
+    "Error occurred when sending invitations" : "Kutsujen lähetyksessä tapahtui virhe",
     "Enable lobby" : "Käytä aulaa",
     "Start time (optional)" : "Aloitusaika (valinnainen)",
+    "Lock conversation" : "Lukitse keskustelu",
+    "Error occurred when locking the conversation" : "Keskustelun lukitsemisessa tapahtui virhe",
     "Save" : "Tallenna",
     "Edit" : "Muokkaa",
+    "More information" : "Lisää tietoa",
+    "Delete" : "Poista",
     "Nextcloud user" : "Nextcloud-käyttäjä",
     "Matrix channel" : "Matrix-kanava",
     "Mattermost user" : "Mattermost-käyttäjä",
@@ -278,6 +313,8 @@ OC.L10N.register(
     "Use SASL" : "Käytä SASL:ia",
     "Client ID" : "Asiakkaan tunniste",
     "Bridge saved" : "Silta tallennettu",
+    "Edit conversation description" : "Muokkaa keskustelun kuvausta",
+    "Mark as read" : "Merkitse luetuksi",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
     "You: {lastMessage}" : "Sinä: {lastMessage}",
@@ -297,15 +334,14 @@ OC.L10N.register(
     "Link copied to the clipboard!" : "Linkki kopioitu leikepöydälle!",
     "Create a new group conversation" : "Luo uusi ryhmäkeskustelu",
     "Password protect" : "Suojaa salasanalla",
-    "Add participants" : "Lisää osallistujat",
     "Create conversation" : "Luo keskustelu",
+    "Add participants" : "Lisää osallistujat",
     "Close" : "Sulje",
     "Choose a password" : "Valitse salasana",
     "Search participants" : "Etsi osallistujia",
     "Conversation name" : "Keskustelun nimi",
     "Search conversations or users" : "Hae keskusteluja tai käyttäjiä",
     "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
     "Calls are not supported in your browser" : "Selaimesi ei tue puheluja",
     "Microphone" : "Mikrofoni",
     "Camera" : "Kamera",
@@ -314,7 +350,19 @@ OC.L10N.register(
     "No camera available" : "Ei kameraa saatavilla",
     "Select camera" : "Valitse kamera",
     "Reply" : "Vastaa",
+    "Reply privately" : "Vastaa yksityisesti",
+    "Copy message link" : "Kopioi viestin linkki",
+    "Mark as unread" : "Merkitse lukemattomaksi",
     "Go to file" : "Siirry tiedostoon",
+    "Unread messages" : "Lukemattomat viestit",
+    "Sending message" : "Lähetetään viestiä",
+    "Message sent" : "Viesti lähetetty",
+    "Failed to send the message. Click to try again" : "Viestin lähettäminen epäonnistui. Paina yrittääksesi uudelleen",
+    "Not enough free space to upload file" : "Ei riittävästi vapaata tilaa tiedoston lähettämiseksi",
+    "Deleting message" : "Poistetaan viestiä",
+    "Message deleted successfully" : "Viesti poistettu onnistuneesti",
+    "Remove {fileName}" : "Poista {fileName}",
+    "Go to conversation" : "Mene keskusteluun",
     "Scroll to bottom" : "Vieritä alas",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
@@ -342,10 +390,12 @@ OC.L10N.register(
     "Add groups or circles" : "Lisää ryhmiä tai piirejä",
     "Add other sources" : "Lisää muita lähteitä",
     "Participants" : "Osallistujat",
+    "Search or add participants" : "Etsi tai lisää osallistujia",
     "Chat" : "Keskustelu",
     "Display name: " : "Näyttönimi:",
     "Choose devices" : "Valitse laitteet",
     "Attachments folder" : "Liitteiden kansio",
+    "Privacy" : "Yksityisyys",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Focus the chat input" : "Kohdista keskustelun syötteeseen",
     "Search" : "Etsi",
@@ -374,6 +424,7 @@ OC.L10N.register(
     "Error while sharing file" : "Virhe tiedostoa jakaessa",
     "Join here" : "Liity tähän",
     "Leave this page" : "Poistu tältä sivulta",
+    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud on huoltotilassa, päivitä sivu",
     "Default" : "Oletus",
     "Microphone {number}" : "Mikrofoni {number}",
     "Camera {number}" : "Kamera {number}",
@@ -408,6 +459,7 @@ OC.L10N.register(
     "Enable video (v)" : "Ota video käyttöön (v)",
     "This conversation is read only" : "Keskustelu on kirjoitussuojattu",
     "Allow guests to join via link " : "Salli vieraiden liittyminen linkin kautta",
+    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Odotat parhaillaan aulassa. Tapaaminen on ajoitettu alkavaksi {startTime}",
     "Remove" : "Poista",
     "Bridge with other services" : "Siltaa muiden palvelujen kanssa",
     "More info on Matterbridge." : "Lisätietoja Matterbridgestä.",
@@ -418,6 +470,10 @@ OC.L10N.register(
     "Share link" : "Jaa linkki",
     "Exit fullscreen (f)" : "Poistu koko näytön tilasta (f)",
     "Fullscreen (f)" : "Koko näytön tila (f)",
-    "Error while uploading file" : "Virhe tiedostoa lähettäessä"
+    "Error while uploading file" : "Virhe tiedostoa lähettäessä",
+    "Lower hand" : "Laske käsi",
+    "Raise hand" : "Nosta käsi",
+    "Conversation \"{conversationName}\"" : "Keskustelu \"{conversationName}\"",
+    "Settings for conversation \"{conversationName}\"" : "Asetukset keskustelulle \"{conversationName}\""
 },
 "nplurals=2; plural=(n != 1);");
