@@ -436,6 +436,7 @@ OC.L10N.register(
     "Conversation name" : "Heiti samtals",
     "Camera" : "Myndavél",
     "Reply" : "Svara",
+    "Go to file" : "Fara í skrá",
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
@@ -455,7 +456,6 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Search" : "Search",
     "Start call" : "Hefja samtal",
-    "Go to file" : "Fara í skrá",
     "Rename conversation" : "Endurnefna samtal",
     "Grid view" : "Reitasýn",
     "Send" : "Senda",
@@ -485,7 +485,6 @@ OC.L10N.register(
     "New in Talk 7" : "Nýtt í Talk 7",
     "{user} wants to talk with you" : "{user} vill tala við þig",
     "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Notendur sem ekki geta lengur notað Talk-spjallforritið verða samt áfram taldir sem þátttakendur í fyrri samtölum sínum og verður einnig haldið upp á spjallskilaboð þeirra.",
-    "Signaling server URL" : "Slóð á merkjasendingaþjón",
     "UDP and TCP" : "UDP og TCP",
     "UDP only" : "Aðeins UDP",
     "TCP only" : "Aðeins TCP",
@@ -496,12 +495,10 @@ OC.L10N.register(
     "Disable video (v)" : "Gera myndskeið óvirk (v)",
     "Enable video (v)" : "Virkja myndskeið (v)",
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Virkja myndskeið (v) - Tengingin þín verður trufluð í stutta stund á meðan myndmerkið er virkjað í fyrsta skipti",
-    "Projects" : "Verkefni",
+    "Remove" : "Fjarlægja",
+    "Enabled" : "Virkt",
     "Share link" : "Deila tengli",
     "Exit fullscreen (f)" : "Hætta í skjáfylli (f)",
-    "Fullscreen (f)" : "Fylla skjáinn (f)",
-    "Select a conversation to add to the project" : "Veldu samtal sem á að bæta við verkefnið",
-    "Remove" : "Fjarlægja",
-    "Enabled" : "Virkt"
+    "Fullscreen (f)" : "Fylla skjáinn (f)"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
