@@ -388,6 +388,7 @@ OC.L10N.register(
     "@-mentions only" : "Tik @ paminėjimai",
     "Off" : "Išjungta",
     "URL of this Nextcloud instance" : "Šio Nextcloud egzemplioriaus URL",
+    "Email of the user" : "Naudotojo el. paštas",
     "Language" : "Kalba",
     "Country" : "Šalis",
     "Status" : "Būsena",
@@ -408,6 +409,7 @@ OC.L10N.register(
     "Phone number (Country)" : "Telefono numeris (Šalis)",
     "Delete this server" : "Ištrinti šį serverį",
     "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
+    "Error: Cannot connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
     "Error: Unknown error occurred" : "Klaida: Įvyko nežinoma klaida",
     "Saved" : "Įrašyta",
     "Add a new server" : "Pridėti naują serverį",
@@ -423,6 +425,8 @@ OC.L10N.register(
     "TURN servers" : "TURN serveriai",
     "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
     "A participant raised their hand." : "Dalyvis pakėlė ranką.",
+    "Previous page of videos" : "Ankstesnis vaizdo įrašų puslapis",
+    "Next page of videos" : "Kitas vaizdo įrašų puslapis",
     "Copy link" : "Kopijuoti nuorodą",
     "Connecting …" : "Jungiamasi…",
     "Waiting for others to join the call …" : "Laukiama, kol kiti prisijungs prie skambučio…",
@@ -463,23 +467,35 @@ OC.L10N.register(
     "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
     "Back" : "Atgal",
     "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
+    "Error while accessing camera: it is likely in use by another program" : "Klaida gaunant prieigą prie kameros: tikėtina, kad ją naudoja kita programa",
     "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
     "You" : "Jūs",
     "Show screen" : "Rodyti ekraną",
     "Mute" : "Nutildyti",
+    "This conversation is read-only" : "Šis pokalbis yra tik skaitymui",
     "Favorite" : "Mėgstamas",
     "Conversation settings" : "Pokalbio nustatymai",
     "Description" : "Aprašas",
     "Chat notifications" : "Pokalbio pranešimai",
+    "Meeting settings" : "Susitikimo nustatymai",
+    "Danger zone" : "Pavojinga zona",
+    "Error while updating conversation description" : "Klaida atnaujinant pokalbio aprašą",
+    "Be careful, these actions cannot be undone." : "Būkite atsargūs, šių veiksmų nebegalėsite atšaukti.",
     "Leave conversation" : "Išeiti iš pokalbio",
     "Delete conversation" : "Ištrinti pokalbį",
     "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
     "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
+    "Error while deleting conversation" : "Klaida ištrinant pokalbį",
     "Password protection" : "Apsauga slaptažodžiu",
     "Enter a password" : "Enter a password",
+    "Save password" : "Įrašyti slaptažodį",
     "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
+    "Invitations sent" : "Pakvietimai išsiųsti",
     "Enable lobby" : "Įjungti laukimo salę",
     "Start time (optional)" : "Pradžios laikas (nebūtinas)",
+    "Lock conversation" : "Užrakinti pokalbį",
+    "Error occurred when locking the conversation" : "Užrakinant pokalbį, įvyko klaida",
+    "Error occurred when unlocking the conversation" : "Atrakinant pokalbį, įvyko klaida",
     "Save" : "Įrašyti",
     "Edit" : "Taisyti",
     "More information" : "Daugiau informacijos",
@@ -489,6 +505,7 @@ OC.L10N.register(
     "User password" : "Naudotojo slaptažodis",
     "Matrix server URL" : "Matrix serverio URL",
     "Matrix channel" : "Matrix kanalas",
+    "Team name" : "Komandos pavadinimas",
     "Channel name" : "Kanalo pavadinimas",
     "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
     "User name or email address" : "Naudotojo vardas ar el. pašto adresas",
@@ -500,6 +517,7 @@ OC.L10N.register(
     "Channel ID or name" : "Kanalo ID ar pavadinimas",
     "Channel" : "Kanalas",
     "Login" : "Prisijungti",
+    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC serverio URL (pvz., chat.freenode.net:6667)",
     "Nickname" : "Slapyvardis",
     "IRC channel" : "IRC kanalas",
     "Use TLS" : "Naudoti TLS",
@@ -514,6 +532,7 @@ OC.L10N.register(
     "Add to favorites" : "Pridėti į mėgstamus",
     "You: {lastMessage}" : "Jūs: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "Open conversations" : "Atverti pokalbius",
     "Loading" : "Įkeliama",
     "No search results" : "Nėra paieškos rezultatų",
     "Groups" : "Grupės",
@@ -531,14 +550,14 @@ OC.L10N.register(
     "Link copied to the clipboard!" : "Nuoroda nukopijuota į iškarpinę!",
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
     "Password protect" : "Apsaugoti slaptažodžiu",
-    "Add participants" : "Pridėti dalyvius",
     "Create conversation" : "Sukurti pokalbį",
+    "Add participants" : "Pridėti dalyvius",
     "Close" : "Užverti",
     "Search participants" : "Ieškoti dalyvių",
     "Conversation name" : "Pokalbio pavadinimas",
+    "Allow guests to join via link" : "Leisti svečiams prisijungti per nuorodą",
     "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
     "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
     "Calls are not supported in your browser" : "Jūsų naršyklėje skambučiai yra nepalaikomi",
     "Access to microphone is only possible with HTTPS" : "Prieiga prie mikrofono yra įmanoma tik naudojant HTTPS",
     "Access to microphone was denied" : "Prieiga prie mikrofono buvo uždrausta",
@@ -551,9 +570,19 @@ OC.L10N.register(
     "No camera available" : "Nėra prieinamos kameros",
     "Select camera" : "Pasirinkti kamerą",
     "Reply" : "Atsakyti",
+    "Reply privately" : "Atsakyti privačiai",
+    "Copy message link" : "Kopijuoti žinutės nuorodą",
     "Mark as unread" : "Žymėti kaip neskaitytą",
     "Go to file" : "Pereiti į failą",
-    "[Unknown username]" : "[Nežinomas naudotojo vardas]",
+    "Forward message" : "Persiųsti žinutę",
+    "Unread messages" : "Neskaitytos žinutės",
+    "Message sent" : "Žinutė išsiųsta",
+    "You are not allowed to share files" : "Jums neleidžiama bendrinti failų",
+    "You cannot send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį",
+    "Message deleted successfully" : "Žinutė sėkmingai ištrinta",
+    "Remove {fileName}" : "Šalinti {fileName}",
+    "Error while forwarding message" : "Klaida persiunčiant žinutę",
+    "Scroll to bottom" : "Slinkti į apačią",
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
@@ -562,12 +591,15 @@ OC.L10N.register(
     "Add emoji" : "Pridėti šypsenėlę",
     "Send message" : "Siųsti žinutę",
     "File to share" : "Failas, kurį bendrinti",
+    "This conversation has been locked" : "Šis pokalbis užrakintas",
     "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
     "Invalid path selected" : "Pasirinktas neteisingas kelias",
+    "Disable lobby" : "Išjungti laukimo salę",
     "moderator" : "moderatorius",
     "guest" : "svečias",
     "Demote from moderator" : "Pažeminti iš moderatorių",
     "Promote to moderator" : "Paaukštinti į moderatorius",
+    "Resend invitation" : "Siųsti pakvietimą iš naujo",
     "Remove participant" : "Šalinti dalyvį",
     "Add groups" : "Pridėti grupes",
     "Add emails" : "Pridėti el. paštus",
@@ -582,6 +614,8 @@ OC.L10N.register(
     "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Chat" : "Pokalbis",
     "Details" : "Išsamiau",
+    "Meeting ID: {meetingId}" : "Susitikimo ID: {meetingId}",
+    "Your PIN: {attendeePin}" : "Jūsų PIN kodas: {attendeePin}",
     "Display name: " : "Rodomas vardas: ",
     "Choose devices" : "Pasirinkti įrenginius",
     "Attachments folder" : "Priedų aplankas",
@@ -613,6 +647,7 @@ OC.L10N.register(
     "Away" : "Atsitraukęs",
     "Error while sharing file" : "Klaida bendrinant failą",
     "Failed to join the conversation. Try to reload the page." : "Nepavyko prisijungti prie pokalbio. Pabandykite įkelti puslapį iš naujo.",
+    "Leave this page" : "Išeiti iš šio puslapio",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
     "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės.",
     "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
@@ -664,7 +699,9 @@ OC.L10N.register(
     "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (v) - Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
     "This conversation is read only" : "Šis pokalbis yra tik skaitymui",
     "Allow guests to join via link " : "Leisti svečiams prisijungti per nuorodą",
+    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
     "Remove" : "Šalinti",
+    "[Unknown username]" : "[Nežinomas naudotojo vardas]",
     "Enabled" : "Įjungta",
     "User name or e-mail address" : "Naudotojo vardas ar el. pašto adresas",
     "Participant settings" : "Dalyvio nustatymai",
@@ -682,6 +719,7 @@ OC.L10N.register(
     "You stopped Matterbridge." : "Jūs sustabdėte „Matterbridge“.",
     "Lower hand" : "Nuleisti ranką",
     "Raise hand" : "Pakelti ranką",
-    "Conversation \"{conversationName}\"" : "Pokalbis „{conversationName}“"
+    "Conversation \"{conversationName}\"" : "Pokalbis „{conversationName}“",
+    "You can not send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
