@@ -19,6 +19,8 @@ OC.L10N.register(
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge e Safari pòdon ara utilizar la conversacion àudio e vidèo",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Podètz ara notificar totes los participants en publicant « @all » al chat",
     "- You can now mention guests in the chat" : "- Podètz ara mencionar los convidats al chat",
+    "- Join the same conversation and call from multiple devices" : "- Participar a la meteissa conversacion e sonada de mantun aparelh estant",
+    "- Send voice messages, share your location or contact details" : "- Enviar de messatges vocals, partejar vòstra posicion e detalhs de contactes",
     "There are currently no commands available." : "Cap de comanda pas disponibla pel moment.",
     "The command does not exist" : "La comanda existís pas",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Una error s’es producha en executant la comanda. Volgatz demandar a l’administrator de verificar los jornals.",
@@ -101,6 +103,9 @@ OC.L10N.register(
     "An administrator removed circle {circle}" : "Un administrator tirèt lo cercle {circle}",
     "{actor} shared a file which is no longer available" : "{actor} partegèt un fichièr qu’es pas pus disponible",
     "You shared a file which is no longer available" : "Partegèretz un fichièr qu'es pas pus disponible",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} configurèt Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
+    "You set up Matterbridge to synchronize this conversation with other chats" : "Avètz configurat Matterbridge per sincronizar aquesta conversacion amb d’autras discussions",
+    "{actor} updated the Matterbridge configuration" : "{actor} actualizèt la configuracion Matterbridge",
     "You updated the Matterbridge configuration" : "Avètz actualizada la configuracion Matterbridge",
     "{actor} removed the Matterbridge configuration" : "{actor} suprimissèt la configuracion Matterbridge",
     "You removed the Matterbridge configuration" : "Avètz suprimida la configuracion Matterbdrige",
@@ -145,6 +150,7 @@ OC.L10N.register(
     "Password request: %s" : "Senhal requerit : %s",
     "Private conversation" : "Conversacion privada",
     "Deleted user (%s)" : "Utilizaire suprimit (%s)",
+    "{user1} shared room {roomName} on {remoteServer} with you" : "{user1} a partejat la sala {roomName} sus {remoteServer} amb vos",
     "{user} in {call}" : "{user} dins {call}",
     "Deleted user in {call}" : "Utilizaire suprimit dins {call}",
     "{guest} (guest) in {call}" : "{guest} (guest) dins {call}",
@@ -156,15 +162,20 @@ OC.L10N.register(
     "{user} replied to your private message" : "{user} a respondut a vòstre messatge privat",
     "{user} replied to your message in conversation {call}" : "{user} a respondut a vòstre messatge dins la conversacion {call}",
     "A deleted user replied to your message in conversation {call}" : "Un utilizaire suprimit a respondut a vòstre messatge dins la conversacion {call}",
+    "{user} mentioned you in conversation {call}" : "{user} vos a mencionat dins la conversacion {call}",
     "A deleted user mentioned you in conversation {call}" : "Un utilizaire suprimit vos a mencionat dins la conversacion {call}",
+    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (convidat) vos a mencionat dins la conversacion {call}",
     "A guest mentioned you in conversation {call}" : "Un convidat vos a mencionat dins la conversacion {call}",
     "View chat" : "Veire lo chat",
+    "{user} invited you to a private conversation" : "{user} vos a convidat a una conversacion privada",
     "Join call" : "Rejónher la sonada",
+    "{user} invited you to a group conversation: {call}" : "{user} vos a convidat a un conversacion de grop : {call}",
     "Answer call" : "Respondre a l’apèl",
     "{user} would like to talk with you" : "{user} volriá vos parlar",
     "Call back" : "Tornar",
     "A group call has started in {call}" : "Una sonada de grop a començat dins {call}",
     "You missed a group call in {call}" : "Avètz mancat una sonada de grop dins {call}",
+    "{email} is requesting the password to access {file}" : "{email} demanda l’accès al fichièr {file}",
     "Someone is requesting the password to access {file}" : "Qualqu’un demanda lo senhal per accedir a {file}",
     "Open settings" : "Dobrir los paramètres",
     "Conversations" : "Discussions",
@@ -434,6 +445,7 @@ OC.L10N.register(
     "Stay in call" : "Demorar en linha",
     "Duplicate session" : "Duplicar la session",
     "Discuss this file" : "Discutir d’aqueste fichièr",
+    "Share this file with others to discuss it" : "Partejar aqueste fichièr amb d’autres per ne discutir",
     "Share this file" : "Partejar aqueste fichièr",
     "Join conversation" : "Rejónher la conversacion",
     "Request password" : "Demandar senhal",
@@ -464,6 +476,7 @@ OC.L10N.register(
     "Default group notification" : "Notificacion de grop per defaut",
     "Allow conversations on files" : "Permetre las conversacions suls fichièrs",
     "All messages" : "Totes los messatges",
+    "@-mentions only" : "@-mencions sonque",
     "Off" : "Atudat",
     "URL of this Nextcloud instance" : "URL d’aquesta instància Nextcloud",
     "Email of the user" : "Email de l’utilizaire",
@@ -480,11 +493,13 @@ OC.L10N.register(
     "Expired" : "Expirat",
     "_%n user_::_%n users_" : ["%n utilizaire","%n utilizaires"],
     "Matterbridge integration" : "Integracion Matterbridge",
+    "Enable Matterbridge integration" : "Activar l’integracion Matterbridge",
     "Downloading …" : "Telecargament…",
     "Install Talk Matterbridge" : "Installar Talk Matterbridge",
     "Installed version: {version}" : "Version installada : {version}",
     "An error occurred while installing the Talk Matterbridge. Please install it manually." : "Una error s’es producha pendent l’installacion de Talk Matterbridge. Volgatz l’installar manualament.",
     "SIP configuration" : "Configuracion SIP",
+    "SIP configuration is only possible with a high-performance backend." : "La configuracion SIP es sonque possibla amb un backend de nauta performança",
     "Enable SIP configuration" : "Activar la configuracion SIP",
     "Shared secret" : "Secret partejat",
     "Phone number (Country)" : "Numèro de telefòn (País)",
@@ -538,6 +553,7 @@ OC.L10N.register(
     "No camera" : "Cap de camèra",
     "Disable video (V)" : "Desactivar la vidèo (V)",
     "Enable video (V)" : "Activar la vidèo (V)",
+    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Activar la vidèo (V) - La connexion serà interrompuda brèvament pendent l’activacion de la vidèo pel primièr còp",
     "Disable video" : "Desactivar la vidèo",
     "Enable video" : "Activar la vidèo",
     "You are not allowed to enable screensharing" : "Avètz pas l'autorizacion per activar lo partiment d’ecran",
@@ -546,11 +562,20 @@ OC.L10N.register(
     "Enable screensharing" : "Activar lo partiment d’ecran",
     "Bad sent video and screen quality." : "Marrida vidèo enviada e qualitat d’ecran.",
     "Bad sent screen quality." : "Marrida qualitat d’ecran enviada.",
+    "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vejan pas vòstre ecran.",
+    "Your internet connection or computer are busy and other participants might be unable to see you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos vejan pas.",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo pendent un partiment d’ecran.",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
     "Disable screenshare" : "Desactivar lo partiment d’ecran",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar la vidèo.",
+    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas.",
     "Screen sharing is not supported by your browser." : "Vòstre navegador pren pas en carga lo partiment d’ecran.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís que la pagina siá cargada via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Lo partiment d’ecran requerís un cargament via HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Lo partiment d’ecran fonciona pas qu’amb Firefox 52 o mai recent.",
     "Screensharing extension is required to share your screen." : "Una extension de partiment d’ecran es requerida per partejar l’ecran.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Volgatz utilizar un navegador diferent coma Firefox o Chrome per partejar l’ecran.",
     "An error occurred while starting screensharing." : "S’es producha una error en aviant lo partiment d’ecran.",
     "Back" : "Retorn",
     "Access to camera was denied" : "L’accès a la camèra es estat refusat",
@@ -579,13 +604,17 @@ OC.L10N.register(
     "Error while updating conversation description" : "Error pendent l’actualizacion de la descripcion de la conversacion",
     "Be careful, these actions cannot be undone." : "Fasètz atencion, aquelas accions pòdon pas èsser anulladas.",
     "Leave conversation" : "Quitar la conversacion",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Un còp quitada, per tornar a un conversacion tampada, cal un convit. Una conversacion dubèrta es totjorn accessibla.",
     "Delete conversation" : "Suprimir la conversacion",
-    "Permanently delete this conversation." : "Suprimir permanent aqueste conversacion",
+    "Permanently delete this conversation." : "Suprimir permanent aquesta conversacion",
     "Delete chat messages" : "Suprimir los messatges del chat",
+    "Permanently delete all the messages in this conversation." : "Suprimir per totjorn totes los messatges d’aquesta conversacion.",
     "Do you really want to delete \"{displayName}\"?" : "Volètz vertadièrament suprimir « {displayName} » ?",
     "Error while deleting conversation" : "Error pendent la supression de la conversacion",
+    "Do you really want to delete all messages in \"{displayName}\"?" : "Volètz vertadièrament suprimir totes los messatges dins « {displayName} » ?",
     "Delete all chat messages" : "Suprimir totes los messatges del chat",
     "Error while clearing chat history" : "Error pendent l’escafament de l’istoric del chat",
+    "Allow guests to use a public link to join this conversation." : "Permetre als convidats d’utilizar un ligam public per rejónher aquesta conversacion.",
     "Allow guests" : "Autorizar los convidats",
     "Set a password to restrict who can use the public link." : "Definir lo senhal per restrénher qual pòt utilizar lo ligam public.",
     "Password protection" : "Protegir via senhal",
@@ -622,6 +651,9 @@ OC.L10N.register(
     "Edit" : "Modificar",
     "More information" : "Mai d’informacions",
     "Delete" : "Suprimir",
+    "More info on Matterbridge" : "Mai d’info sus Matterbridge",
+    "Enable bridge" : "Activar lo pont",
+    "Show Matterbridge log" : "Veire los jornals de Matterbridge",
     "Nextcloud URL" : "URL Nextcloud",
     "Nextcloud user" : "Utilizaire Nextcloud",
     "User password" : "Senhal utilizaire",
@@ -632,19 +664,23 @@ OC.L10N.register(
     "Mattermost user" : "Utilizaire Mattermost",
     "Team name" : "Nom de la còla",
     "Channel name" : "Nom de la cadena",
+    "Rocket.Chat server URL" : "URL del servidor Rocket.Chat",
     "User name or email address" : "Nom d’utilizaire o adreça email",
     "Password" : "Senhal",
+    "Rocket.Chat channel" : "Canal Rocket.Chat",
     "Skip TLS verification" : "Passar la verificacion TLS",
     "Zulip server URL" : "URL servidor Zulip",
     "Bot user name" : "Nom d’utilizaire robòt",
     "Bot API key" : "Clau d’API robòt",
     "Zulip channel" : "Canal Zulip",
     "API token" : "Geton API",
+    "Slack channel" : "Canal Slack",
     "Server ID or name" : "ID o nom del servidor",
     "Channel ID or name" : "ID o nom del canal",
     "Channel" : "Cadena",
     "Login" : "Login",
     "Chat ID" : "ID del chat",
+    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL servidor IRC (per exemple chat.freenode.net:6667)",
     "Nickname" : "Escais",
     "Connection password" : "Senhal de connexion",
     "IRC channel" : "Cadena IRC",
@@ -663,6 +699,7 @@ OC.L10N.register(
     "unknown state" : "estat desconegut",
     "running" : "en cors d'execucion",
     "not running" : "pas en execucion",
+    "Bridge saved" : "Pont enregistrat",
     "Cancel editing description" : "Anullar la modificacion de la descripcion",
     "Submit conversation description" : "Enviar la descripcion de la conversacion",
     "Edit conversation description" : "Editar la descripcion de la conversacion",
@@ -681,6 +718,8 @@ OC.L10N.register(
     "Circles" : "Cercles",
     "Talk settings" : "Paramètres Talk",
     "Users and groups" : "Utilizaires e grops",
+    "Users and circles" : "Utilizaires e cercles",
+    "Groups and circles" : "Grops e cercles",
     "Other sources" : "Autras fonts",
     "An error occurred while performing the search" : "Una error s'es producha en realizant la recèrca",
     "Creating your conversation" : "Creacion de vòstra conversacion",
@@ -689,8 +728,8 @@ OC.L10N.register(
     "Link copied to the clipboard!" : "Ligam copiat al quichapapièrs !",
     "Create a new group conversation" : "Crear una conversacion de grop novèla",
     "Password protect" : "Protegir per un senhal",
-    "Add participants" : "Apondre participants",
     "Create conversation" : "Crear conversacion",
+    "Add participants" : "Apondre participants",
     "Close" : "Tampar",
     "Choose a password" : "Causir un senhal",
     "Search participants" : "Cercar participants",
@@ -698,7 +737,8 @@ OC.L10N.register(
     "Allow guests to join via link" : "Permetre als convidats de rejónher via ligam",
     "Search conversations or users" : "Cercar de conversacions o utilizaires",
     "You are currently waiting in the lobby" : "Sètz a esperar dins la sala d’espèra",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Sètz a esperar dins la sala d’espèra. Aquesta conferéncia es planificada per {startTime}",
+    "The meeting will start soon" : "La conferéncia començarà lèu",
+    "This meeting is scheduled for {startTime}" : "La conferéncia es planificada per {startTime}",
     "Calls are not supported in your browser" : "Vòstre navegador pren pas encarga las sonadas",
     "Access to microphone is only possible with HTTPS" : "L’accès al microfòn es sonque possibla amb HTTPS",
     "Access to microphone was denied" : "L’accès al microfòn es estat refusat",
@@ -732,9 +772,10 @@ OC.L10N.register(
     "Contact" : "Contacte",
     "{stack} in {board}" : "{stack} dins {board}",
     "Remove {fileName}" : "Suprimir {fileName}",
+    "The message has been forwarded to {selectedConversationName}" : "Lo messatge es estat transferit a {selectedConversationName}",
     "Go to conversation" : "Anar a la conversacion",
-    "Open this location in Openstreetmap" : "Dobrir aqueste lòc dins Openstreetmap",
-    "[Unknown username]" : "[utilizaire desconegut]",
+    "Choose a conversation to forward the selected message." : "Causir una conversacion destinària del messatge seleccionat.",
+    "Error while forwarding message" : "Error en transferissent lo messatge",
     "Scroll to bottom" : "Desfilar enbàs",
     "Today" : "Uèi",
     "Yesterday" : "Ièr",
@@ -791,6 +832,7 @@ OC.L10N.register(
     "Privacy" : "Confidencialitat",
     "Sounds" : "Sons",
     "Play sounds when participants join or leave a call" : "Emetre sons quand los participants rejonhon o quitan una sonada",
+    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Los sons pòdon pas èsser legits dins lo navegador Safari e los aparelhs iPad e iPhone a causa d’una restriccion tecnica del fabricant.",
     "Keyboard shortcuts" : "Acorchis de clavièr",
     "Speed up your Talk experience with these quick shortcuts." : "Acceleratz vòstra experiéncia Talk amb aqueles acorchis.",
     "Fullscreen the chat or call" : "Passar la messatjariá o la sonada en plen ecran",
@@ -842,6 +884,7 @@ OC.L10N.register(
     "Do not disturb" : "Me desrengar pas",
     "Away" : "Absent",
     "Error while sharing file" : "Error pendent lo partiment del fichièr",
+    "Error while clearing conversation history" : "Error pendent escafament de l’istoric de la conversacion",
     "Not enough free space to upload file \"{fileName}\"" : "Pas pro d’espaci liure per enviar lo fichièr « {fileName} »",
     "Error while uploading file \"{fileName}\"" : "Error en enviant lo fichièr « {fileName} »",
     "An error happened when trying to share your file" : "Una error s’es producha en ensajant de partejar vòstre fichièr",
@@ -850,6 +893,7 @@ OC.L10N.register(
     "Sending signaling message has failed." : "Lo mandadís de messatge de senhalament a pas reüssit.",
     "Lost connection to signaling server. Trying to reconnect." : "Connexion perduda al servidor de senhalament. Ensag de reconnexion.",
     "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament.",
+    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Fracàs de l’establiment de la connexion de senhalizacion. Quicòm pòt èsser maridament configurat costat servidor.",
     "Default" : "Defaut",
     "Microphone {number}" : "Microfòn {number}",
     "Camera {number}" : "Camèra {number}",
@@ -891,7 +935,9 @@ OC.L10N.register(
     "This conversation is read only" : "La conversacion es en lectura sola",
     "Conversation, " : "Conversacion, ",
     "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
+    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Sètz a esperar dins la sala d’espèra. Aquesta conferéncia es planificada per {startTime}",
     "Remove" : "Suprimir",
+    "[Unknown username]" : "[utilizaire desconegut]",
     "More info on Matterbridge." : "Mai d‘informacions sus Matterbridge.",
     "Enabled" : "Activada",
     "User name or e-mail address" : "Nom d’utilizaire o adreça electronica",
@@ -915,6 +961,7 @@ OC.L10N.register(
     "Conversation \"{conversationName}\"" : "Conversacion « {conversationName} »",
     "Settings for conversation \"{conversationName}\"" : "Paramètres per la conversacion « {conversationName} »",
     "You can not send messages to this conversation at the moment" : "Podètz pas enviar de messatges a aquesta conversacion pel moment",
-    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion"
+    "Add a description for this conversation" : "Apondètz una descripcion per aquesta conversacion",
+    "Open this location in Openstreetmap" : "Dobrir aqueste lòc dins Openstreetmap"
 },
 "nplurals=2; plural=(n > 1);");
